Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(266)

Unified Diff: net/test/base_test_server.h

Issue 10412042: Improve the TLS intolerant server testing support added in r134129 (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Tweak enumerator names Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | net/test/base_test_server.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/test/base_test_server.h
===================================================================
--- net/test/base_test_server.h (revision 138367)
+++ net/test/base_test_server.h (working copy)
@@ -85,6 +85,15 @@
BULK_CIPHER_3DES = (1 << 3),
};
+ // NOTE: the values of these enumerators are passed to the the Python test
+ // server. Do not change them.
+ enum TLSIntolerantLevel {
+ TLS_INTOLERANT_NONE = 0,
+ TLS_INTOLERANT_ALL = 1, // Intolerant of all TLS versions.
+ TLS_INTOLERANT_TLS1_1 = 2, // Intolerant of TLS 1.1 or higher.
+ TLS_INTOLERANT_TLS1_2 = 3, // Intolerant of TLS 1.2 or higher.
+ };
+
// Initialize a new HTTPSOptions using CERT_OK as the certificate.
HTTPSOptions();
@@ -127,9 +136,9 @@
// /ssl-session-cache.
bool record_resume;
- // If true, the server will abort any TLS handshake in order to test
- // SSLv3 fallback.
- bool tls_intolerant;
+ // If not TLS_INTOLERANT_NONE, the server will abort any handshake that
+ // negotiates an intolerant TLS version in order to test version fallback.
+ TLSIntolerantLevel tls_intolerant;
};
// Pass as the 'host' parameter during construction to server on 127.0.0.1
« no previous file with comments | « no previous file | net/test/base_test_server.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698